==> zio-aws-ec2_2.12-7.21.15.11-sources.jar: zio/aws/ec2/model/ModifyNetworkInterfaceAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{NetworkInterfaceId, SecurityGroupId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyNetworkInterfaceAttributeRequest(
    attachment: Optional[zio.aws.ec2.model.NetworkInterfaceAttachmentChanges] =
      Optional.Absent,
    description: Optional[zio.aws.ec2.model.AttributeValue] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent,
    groups: Optional[Iterable[SecurityGroupId]] = Optional.Absent,
    networkInterfaceId: NetworkInterfaceId,
    sourceDestCheck: Optional[zio.aws.ec2.model.AttributeBooleanValue] =
      Optional.Absent,
    enaSrdSpecification: Optional[zio.aws.ec2.model.EnaSrdSpecification] =
      Optional.Absent,
    enablePrimaryIpv6: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest = {
    import ModifyNetworkInterfaceAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
      .builder()
      .optionallyWith(attachment.map(value => value.buildAwsValue()))(
        _.attachment
      )
      .optionallyWith(description.map(value => value.buildAwsValue()))(
        _.description
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        groups.map(value =>
          value.map { item =>
            SecurityGroupId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.groups)
      .networkInterfaceId(
        NetworkInterfaceId.unwrap(networkInterfaceId): java.lang.String
      )
      .optionallyWith(sourceDestCheck.map(value => value.buildAwsValue()))(
        _.sourceDestCheck
      )
      .optionallyWith(enaSrdSpecification.map(value => value.buildAwsValue()))(
        _.enaSrdSpecification
      )
      .optionallyWith(enablePrimaryIpv6.map(value => value: java.lang.Boolean))(
        _.enablePrimaryIpv6
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest.ReadOnly =
    zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest
      .wrap(buildAwsValue())
}
object ModifyNetworkInterfaceAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest =
      zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest(
        attachment.map(value => value.asEditable),
        description.map(value => value.asEditable),
        dryRun.map(value => value),
        groups.map(value => value),
        networkInterfaceId,
        sourceDestCheck.map(value => value.asEditable),
        enaSrdSpecification.map(value => value.asEditable),
        enablePrimaryIpv6.map(value => value)
      )
    def attachment
        : Optional[zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.ReadOnly]
    def description: Optional[zio.aws.ec2.model.AttributeValue.ReadOnly]
    def dryRun: Optional[Boolean]
    def groups: Optional[List[SecurityGroupId]]
    def networkInterfaceId: NetworkInterfaceId
    def sourceDestCheck
        : Optional[zio.aws.ec2.model.AttributeBooleanValue.ReadOnly]
    def enaSrdSpecification
        : Optional[zio.aws.ec2.model.EnaSrdSpecification.ReadOnly]
    def enablePrimaryIpv6: Optional[Boolean]
    def getAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.ReadOnly
    ] = AwsError.unwrapOptionField("attachment", attachment)
    def getDescription
        : ZIO[Any, AwsError, zio.aws.ec2.model.AttributeValue.ReadOnly] =
      AwsError.unwrapOptionField("description", description)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getGroups: ZIO[Any, AwsError, List[SecurityGroupId]] =
      AwsError.unwrapOptionField("groups", groups)
    def getNetworkInterfaceId: ZIO[Any, Nothing, NetworkInterfaceId] =
      ZIO.succeed(networkInterfaceId)
    def getSourceDestCheck
        : ZIO[Any, AwsError, zio.aws.ec2.model.AttributeBooleanValue.ReadOnly] =
      AwsError.unwrapOptionField("sourceDestCheck", sourceDestCheck)
    def getEnaSrdSpecification
        : ZIO[Any, AwsError, zio.aws.ec2.model.EnaSrdSpecification.ReadOnly] =
      AwsError.unwrapOptionField("enaSrdSpecification", enaSrdSpecification)
    def getEnablePrimaryIpv6: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enablePrimaryIpv6", enablePrimaryIpv6)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
  ) extends zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest.ReadOnly {
    override val attachment: Optional[
      zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.attachment())
      .map(value =>
        zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.wrap(value)
      )
    override val description
        : Optional[zio.aws.ec2.model.AttributeValue.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value => zio.aws.ec2.model.AttributeValue.wrap(value))
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val groups: Optional[List[SecurityGroupId]] = zio.aws.core.internal
      .optionalFromNullable(impl.groups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.SecurityGroupId(item)
        }.toList
      )
    override val networkInterfaceId: NetworkInterfaceId =
      zio.aws.ec2.model.primitives.NetworkInterfaceId(impl.networkInterfaceId())
    override val sourceDestCheck
        : Optional[zio.aws.ec2.model.AttributeBooleanValue.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceDestCheck())
        .map(value => zio.aws.ec2.model.AttributeBooleanValue.wrap(value))
    override val enaSrdSpecification
        : Optional[zio.aws.ec2.model.EnaSrdSpecification.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enaSrdSpecification())
        .map(value => zio.aws.ec2.model.EnaSrdSpecification.wrap(value))
    override val enablePrimaryIpv6: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enablePrimaryIpv6())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
  ): zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.104.13-sources.jar: zio/aws/ec2/model/ModifyNetworkInterfaceAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{NetworkInterfaceId, SecurityGroupId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyNetworkInterfaceAttributeRequest(
    attachment: Option[zio.aws.ec2.model.NetworkInterfaceAttachmentChanges] =
      None,
    description: Option[zio.aws.ec2.model.AttributeValue] = None,
    groups: Option[Iterable[SecurityGroupId]] = None,
    networkInterfaceId: NetworkInterfaceId,
    sourceDestCheck: Option[zio.aws.ec2.model.AttributeBooleanValue] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest = {
    import ModifyNetworkInterfaceAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
      .builder()
      .optionallyWith(attachment.map(value => value.buildAwsValue()))(
        _.attachment
      )
      .optionallyWith(description.map(value => value.buildAwsValue()))(
        _.description
      )
      .optionallyWith(
        groups.map(value =>
          value.map { item =>
            SecurityGroupId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.groups)
      .networkInterfaceId(
        NetworkInterfaceId.unwrap(networkInterfaceId): java.lang.String
      )
      .optionallyWith(sourceDestCheck.map(value => value.buildAwsValue()))(
        _.sourceDestCheck
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest.ReadOnly =
    zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest
      .wrap(buildAwsValue())
}
object ModifyNetworkInterfaceAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest =
      zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest(
        attachment.map(value => value.asEditable),
        description.map(value => value.asEditable),
        groups.map(value => value),
        networkInterfaceId,
        sourceDestCheck.map(value => value.asEditable)
      )
    def attachment
        : Option[zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.ReadOnly]
    def description: Option[zio.aws.ec2.model.AttributeValue.ReadOnly]
    def groups: Option[List[SecurityGroupId]]
    def networkInterfaceId: NetworkInterfaceId
    def sourceDestCheck
        : Option[zio.aws.ec2.model.AttributeBooleanValue.ReadOnly]
    def getAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.ReadOnly
    ] = AwsError.unwrapOptionField("attachment", attachment)
    def getDescription
        : ZIO[Any, AwsError, zio.aws.ec2.model.AttributeValue.ReadOnly] =
      AwsError.unwrapOptionField("description", description)
    def getGroups: ZIO[Any, AwsError, List[SecurityGroupId]] =
      AwsError.unwrapOptionField("groups", groups)
    def getNetworkInterfaceId: ZIO[Any, Nothing, NetworkInterfaceId] =
      ZIO.succeed(networkInterfaceId)
    def getSourceDestCheck
        : ZIO[Any, AwsError, zio.aws.ec2.model.AttributeBooleanValue.ReadOnly] =
      AwsError.unwrapOptionField("sourceDestCheck", sourceDestCheck)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
  ) extends zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest.ReadOnly {
    override val attachment
        : Option[zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.ReadOnly] =
      scala
        .Option(impl.attachment())
        .map(value =>
          zio.aws.ec2.model.NetworkInterfaceAttachmentChanges.wrap(value)
        )
    override val description
        : Option[zio.aws.ec2.model.AttributeValue.ReadOnly] = scala
      .Option(impl.description())
      .map(value => zio.aws.ec2.model.AttributeValue.wrap(value))
    override val groups: Option[List[SecurityGroupId]] = scala
      .Option(impl.groups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.SecurityGroupId(item)
        }.toList
      )
    override val networkInterfaceId: NetworkInterfaceId =
      zio.aws.ec2.model.primitives.NetworkInterfaceId(impl.networkInterfaceId())
    override val sourceDestCheck
        : Option[zio.aws.ec2.model.AttributeBooleanValue.ReadOnly] = scala
      .Option(impl.sourceDestCheck())
      .map(value => zio.aws.ec2.model.AttributeBooleanValue.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyNetworkInterfaceAttributeRequest
  ): zio.aws.ec2.model.ModifyNetworkInterfaceAttributeRequest.ReadOnly =
    new Wrapper(impl)
}
